@@ -19,7 +19,8 @@ dt_footnotes_init <- function(data) {
     locnum = numeric(0),
     rownum = integer(0),
     colnum = integer(0),
-    footnotes = list(character(0))
+    footnotes = list(character(0)),
+    placement = character(0)
   ) %>%
     dt_footnotes_set(footnotes = ., data = data)
 }
@@ -31,7 +32,8 @@ dt_footnotes_add <- function(
     colname,
     locnum,
     rownum,
-    footnotes
+    footnotes,
+    placement
 ) {
 
   data %>%
@@ -48,10 +50,11 @@ dt_footnotes_add <- function(
           locname = locname,
           locnum = locnum,
           colnum = NA_integer_,
-          footnotes = list(footnotes)
+          footnotes = list(footnotes),
+          placement = placement,
         ) %>%
         dplyr::distinct() %>%
-        dplyr::select(locname, grpname, colname, locnum, rownum, footnotes)
+        dplyr::select(locname, grpname, colname, locnum, rownum, footnotes, placement)
     ) %>%
     dt_footnotes_set(footnotes = ., data = data)
 }
