@@ -69,6 +69,9 @@ dt_groups_rows_build <- function(data, context) {
       dt_options_get_value(data = data, option = "row_group_default_label")
 
     groups_rows[is.na(groups_rows[, "group_id"]), "group_label"] <- others_group
+  } else {
+    # Resulting data frame must always have the same columns
+    groups_rows <- cbind(groups_rows, group_label = character(0))
   }
 
   data <- dt_groups_rows_set(data = data, groups_rows = groups_rows)
