@@ -14,17 +14,18 @@ dt_heading_init <- function(data) {
 
   list(
     title = NULL,
-    subtitle = NULL
+    subtitle = NULL,
+    preheader = NULL
   ) %>%
     dt_heading_set(heading = ., data = data)
 }
 
-dt_heading_title_subtitle <- function(data, title, subtitle) {
+dt_set_heading_components <- function(data, title, subtitle, preheader) {
 
   heading <- dt_heading_get(data = data)
 
-  heading[c("title", "subtitle")] <-
-    list(title = title, subtitle = subtitle)
+  heading[c("title", "subtitle", "preheader")] <-
+    list(title = title, subtitle = subtitle, preheader = preheader)
 
   dt_heading_set(data = data, heading = heading)
 }
@@ -51,3 +52,10 @@ dt_heading_has_subtitle <- function(data) {
 
   length(heading) > 0 && is_nonempty_string(heading$subtitle)
 }
+
+dt_heading_has_preheader <- function(data) {
+
+  heading <- dt_heading_get(data = data)
+
+  length(heading$preheader) > 0
+}
