@@ -16,8 +16,7 @@
 #' - `"numbers"`: numeric marks, they begin from 1 and these marks are not
 #' subject to recycling behavior
 #' - `"letters"`: miniscule alphabetic marks, internally uses the `letters`
-#' vector
-#' which contains 26 lowercase letters of the Roman alphabet
+#' vector which contains 26 lowercase letters of the Roman alphabet
 #' - `"LETTERS"`: majuscule alphabetic marks, using the `LETTERS` vector
 #' which has 26 uppercase letters of the Roman alphabet
 #' - `"standard"`: symbolic marks, four symbols in total
@@ -34,63 +33,67 @@
 #'
 #' @return An object of class `gt_tbl`.
 #'
-#' @examples
-#' # Use `sza` to create a gt table,
-#' # adding three footnotes; call
-#' # `opt_footnote_marks()` to specify
-#' # which footnote marks to use
-#' tab_1 <-
-#'   sza %>%
-#'     dplyr::filter(latitude == 30) %>%
-#'     dplyr::group_by(tst) %>%
-#'     dplyr::summarize(
-#'       SZA.Max = if (
-#'         all(is.na(sza))) {
-#'         NA
-#'       } else {
-#'         max(sza, na.rm = TRUE)
-#'       },
-#'       SZA.Min = if (
-#'         all(is.na(sza))) {
-#'         NA
-#'       } else {
-#'         min(sza, na.rm = TRUE)
-#'       },
-#'       .groups = "drop"
-#'     ) %>%
-#'     gt(rowname_col = "tst") %>%
-#'     tab_spanner_delim(delim = ".") %>%
-#'     fmt_missing(
-#'       columns = everything(),
-#'       missing_text = "90+"
-#'     ) %>%
-#'     tab_stubhead(label = "TST") %>%
-#'     tab_footnote(
-#'       footnote = "True solar time.",
-#'       locations = cells_stubhead()
-#'     ) %>%
-#'     tab_footnote(
-#'       footnote = "Solar zenith angle.",
-#'       locations = cells_column_spanners(
-#'         spanners = "SZA.Max"
-#'       )
-#'     ) %>%
-#'     tab_footnote(
-#'       footnote = "The Lowest SZA.",
-#'       locations = cells_stub(rows = "1200")
-#'     ) %>%
-#'     opt_footnote_marks(marks = "standard")
+#' @section Examples:
 #'
-#' @section Figures:
-#' \if{html}{\figure{man_opt_footnote_marks_1.png}{options: width=100\%}}
+#' Use [`sza`] to create a **gt** table, adding three footnotes. Call
+#' `opt_footnote_marks()` to specify which footnote marks to use.
+#'
+#' ```r
+#' sza %>%
+#'   dplyr::filter(latitude == 30) %>%
+#'   dplyr::group_by(tst) %>%
+#'   dplyr::summarize(
+#'     SZA.Max = if (
+#'       all(is.na(sza))) {
+#'       NA
+#'     } else {
+#'       max(sza, na.rm = TRUE)
+#'     },
+#'     SZA.Min = if (
+#'       all(is.na(sza))) {
+#'       NA
+#'     } else {
+#'       min(sza, na.rm = TRUE)
+#'     },
+#'     .groups = "drop"
+#'   ) %>%
+#'   gt(rowname_col = "tst") %>%
+#'   tab_spanner_delim(delim = ".") %>%
+#'   sub_missing(
+#'     columns = everything(),
+#'     missing_text = "90+"
+#'   ) %>%
+#'   tab_stubhead(label = "TST") %>%
+#'   tab_footnote(
+#'     footnote = "True solar time.",
+#'     locations = cells_stubhead()
+#'   ) %>%
+#'   tab_footnote(
+#'     footnote = "Solar zenith angle.",
+#'     locations = cells_column_spanners(
+#'       spanners = "SZA.Max"
+#'     )
+#'   ) %>%
+#'   tab_footnote(
+#'     footnote = "The Lowest SZA.",
+#'     locations = cells_stub(rows = "1200")
+#'   ) %>%
+#'   opt_footnote_marks(marks = "standard")
+#' ```
+#'
+#' \if{html}{\out{
+#' `r man_get_image_tag(file = "man_opt_footnote_marks_1.png")`
+#' }}
 #'
 #' @family Table Option Functions
 #' @section Function ID:
 #' 9-1
 #'
 #' @export
-opt_footnote_marks <- function(data,
-                               marks) {
+opt_footnote_marks <- function(
+    data,
+    marks
+) {
 
   # Perform input object validation
   stop_if_not_gt(data = data)
@@ -115,13 +118,14 @@ opt_footnote_marks <- function(data,
 #'
 #' @return An object of class `gt_tbl`.
 #'
-#' @examples
-#' # Use `exibble` to create a gt table with
-#' # a number of table parts added; next, we
-#' # add row striping to every second row with
-#' # the `opt_row_striping()` function
-#' tab_1 <-
-#'   exibble %>%
+#' @section Examples:
+#'
+#' Use [`exibble`] to create a **gt** table with a number of table parts added.
+#' Next, we add row striping to every second row with the `opt_row_striping()`
+#' function.
+#'
+#' ```r
+#' exibble %>%
 #'   gt(rowname_col = "row", groupname_col = "group") %>%
 #'   summary_rows(
 #'     groups = "grp_a",
@@ -145,17 +149,21 @@ opt_footnote_marks <- function(data,
 #'     subtitle = "The table's subtitle"
 #'   ) %>%
 #'   opt_row_striping()
+#' ```
 #'
-#' @section Figures:
-#' \if{html}{\figure{man_opt_row_striping_1.png}{options: width=100\%}}
+#' \if{html}{\out{
+#' `r man_get_image_tag(file = "man_opt_row_striping_1.png")`
+#' }}
 #'
 #' @family Table Option Functions
 #' @section Function ID:
 #' 9-2
 #'
 #' @export
-opt_row_striping <- function(data,
-                             row_striping = TRUE) {
+opt_row_striping <- function(
+    data,
+    row_striping = TRUE
+) {
 
   # Perform input object validation
   stop_if_not_gt(data = data)
@@ -181,14 +189,14 @@ opt_row_striping <- function(data,
 #'
 #' @return An object of class `gt_tbl`.
 #'
-#' @examples
-#' # Use `exibble` to create a gt table with
-#' # a number of table parts added; the header
-#' # (consisting of the title and the subtitle)
-#' # are to be aligned to the left with the
-#' # `opt_align_table_header()` function
-#' tab_1 <-
-#'   exibble %>%
+#' @section Examples:
+#'
+#' Use [`exibble`] to create a **gt** table with a number of table parts added.
+#' The header (consisting of the title and the subtitle) are to be aligned to
+#' the left with the `opt_align_table_header()` function.
+#'
+#' ```r
+#' exibble %>%
 #'   gt(rowname_col = "row", groupname_col = "group") %>%
 #'   summary_rows(
 #'     groups = "grp_a",
@@ -212,17 +220,21 @@ opt_row_striping <- function(data,
 #'     subtitle = "The table's subtitle"
 #'   ) %>%
 #'   opt_align_table_header(align = "left")
+#' ```
 #'
-#' @section Figures:
-#' \if{html}{\figure{man_opt_align_table_header_1.png}{options: width=100\%}}
+#' \if{html}{\out{
+#' `r man_get_image_tag(file = "man_opt_align_table_header_1.png")`
+#' }}
 #'
 #' @family Table Option Functions
 #' @section Function ID:
 #' 9-3
 #'
 #' @export
-opt_align_table_header <- function(data,
-                                   align = c("left", "center", "right")) {
+opt_align_table_header <- function(
+    data,
+    align = c("left", "center", "right")
+) {
 
   # Perform input object validation
   stop_if_not_gt(data = data)
@@ -258,13 +270,15 @@ opt_align_table_header <- function(data,
 #'
 #' @return An object of class `gt_tbl`.
 #'
-#' @examples
-#' # Use `exibble` to create a gt table with
-#' # a number of table parts added; contract
-#' # the vertical padding across the entire
-#' # table with `opt_vertical_padding()`
-#' tab_1 <-
-#'   exibble %>%
+#' @section Examples:
+#'
+#' Use [`exibble`] to create a **gt** table with a number of table parts added.
+#' Contract the vertical padding across the entire table with
+#' `opt_vertical_padding()`.
+#'
+#'
+#' ```r
+#' exibble %>%
 #'   gt(rowname_col = "row", groupname_col = "group") %>%
 #'   summary_rows(
 #'     groups = "grp_a",
@@ -288,17 +302,21 @@ opt_align_table_header <- function(data,
 #'     subtitle = "The table's subtitle"
 #'   ) %>%
 #'   opt_vertical_padding(scale = 0.25)
+#' ```
 #'
-#' @section Figures:
-#' \if{html}{\figure{man_opt_vertical_padding_1.png}{options: width=100\%}}
+#' \if{html}{\out{
+#' `r man_get_image_tag(file = "man_opt_vertical_padding_1.png")`
+#' }}
 #'
 #' @family Table Option Functions
 #' @section Function ID:
 #' 9-4
 #'
 #' @export
-opt_vertical_padding <- function(data,
-                                 scale = 1) {
+opt_vertical_padding <- function(
+    data,
+    scale = 1
+) {
 
   option_value_list <-
     get_padding_option_value_list(
@@ -335,13 +353,14 @@ opt_vertical_padding <- function(data,
 #'
 #' @return An object of class `gt_tbl`.
 #'
-#' @examples
-#' # Use `exibble` to create a gt table with
-#' # a number of table parts added; expand
-#' # the horizontal padding across the entire
-#' # table with `opt_horizontal_padding()`
-#' tab_1 <-
-#'   exibble %>%
+#' @section Examples:
+#'
+#' Use [`exibble`] to create a **gt** table with a number of table parts added.
+#' Expand the horizontal padding across the entire table with
+#' `opt_horizontal_padding()`.
+#'
+#' ```r
+#' exibble %>%
 #'   gt(rowname_col = "row", groupname_col = "group") %>%
 #'   summary_rows(
 #'     groups = "grp_a",
@@ -365,17 +384,21 @@ opt_vertical_padding <- function(data,
 #'     subtitle = "The table's subtitle"
 #'   ) %>%
 #'   opt_horizontal_padding(scale = 3)
+#' ```
 #'
-#' @section Figures:
-#' \if{html}{\figure{man_opt_horizontal_padding_1.png}{options: width=100\%}}
+#' \if{html}{\out{
+#' `r man_get_image_tag(file = "man_opt_horizontal_padding_1.png")`
+#' }}
 #'
 #' @family Table Option Functions
 #' @section Function ID:
 #' 9-5
 #'
 #' @export
-opt_horizontal_padding <- function(data,
-                                   scale = 1) {
+opt_horizontal_padding <- function(
+    data,
+    scale = 1
+) {
 
   option_value_list <-
     get_padding_option_value_list(
@@ -447,14 +470,14 @@ get_padding_option_value_list <- function(scale, type) {
 #'
 #' @return An object of class `gt_tbl`.
 #'
-#' @examples
-#' # Use `exibble` to create a gt table with
-#' # a number of table parts added; all text
-#' # in the column labels, the stub, and in
-#' # all row groups is to be transformed to
-#' # all caps using `opt_all_caps()`
-#' tab_1 <-
-#'   exibble %>%
+#' @section Examples:
+#'
+#' Use [`exibble`] to create a **gt** table with a number of table parts added.
+#' All text in the column labels, the stub, and in all row groups is to be
+#' transformed to all caps using `opt_all_caps()`.
+#'
+#' ```r
+#' exibble %>%
 #'   gt(rowname_col = "row", groupname_col = "group") %>%
 #'   summary_rows(
 #'     groups = "grp_a",
@@ -478,18 +501,22 @@ get_padding_option_value_list <- function(scale, type) {
 #'     subtitle = "The table's subtitle"
 #'   ) %>%
 #'   opt_all_caps()
+#' ```
 #'
-#' @section Figures:
-#' \if{html}{\figure{man_opt_all_caps_1.png}{options: width=100\%}}
+#' \if{html}{\out{
+#' `r man_get_image_tag(file = "man_opt_all_caps_1.png")`
+#' }}
 #'
 #' @family Table Option Functions
 #' @section Function ID:
 #' 9-6
 #'
 #' @export
-opt_all_caps <- function(data,
-                         all_caps = TRUE,
-                         locations = c("column_labels", "stub", "row_group")) {
+opt_all_caps <- function(
+    data,
+    all_caps = TRUE,
+    locations = c("column_labels", "stub", "row_group")
+) {
 
   # Perform input object validation
   stop_if_not_gt(data = data)
@@ -549,14 +576,14 @@ opt_all_caps <- function(data,
 #'
 #' @return An object of class `gt_tbl`.
 #'
-#' @examples
-#' # Use `exibble` to create a gt table with
-#' # a number of table parts added; then, use
-#' # the `opt_table_lines()` function to
-#' # haves lines everywhere there can possibly
-#' # be lines
-#' tab_1 <-
-#'   exibble %>%
+#' @section Examples:
+#'
+#' Use [`exibble`] to create a **gt** table with a number of table parts added.
+#' Then, use the `opt_table_lines()` function to haves lines everywhere there
+#' can possibly be lines.
+#'
+#' ```r
+#' exibble %>%
 #'   gt(rowname_col = "row", groupname_col = "group") %>%
 #'   summary_rows(
 #'     groups = "grp_a",
@@ -580,17 +607,21 @@ opt_all_caps <- function(data,
 #'     subtitle = "The table's subtitle"
 #'   ) %>%
 #'   opt_table_lines()
+#' ```
 #'
-#' @section Figures:
-#' \if{html}{\figure{man_opt_table_lines_1.png}{options: width=100\%}}
+#' \if{html}{\out{
+#' `r man_get_image_tag(file = "man_opt_table_lines_1.png")`
+#' }}
 #'
 #' @family Table Option Functions
 #' @section Function ID:
 #' 9-7
 #'
 #' @export
-opt_table_lines <- function(data,
-                            extent = c("all", "none", "default")) {
+opt_table_lines <- function(
+    data,
+    extent = c("all", "none", "default")
+) {
 
   # Perform input object validation
   stop_if_not_gt(data = data)
@@ -632,11 +663,12 @@ opt_table_lines <- function(data,
 #'
 #' @return An object of class `gt_tbl`.
 #'
-#' @examples
-#' # Use `exibble` to create a gt table with
-#' # a number of table parts added; have an
-#' # outline wrap around the entire table by
-#' # using `opt_table_outline()`
+#' @section Examples:
+#'
+#' Use [`exibble`] to create a **gt** table with a number of table parts added.
+#' Have an outline wrap around the entire table by using `opt_table_outline()`.
+#'
+#' ```r
 #' tab_1 <-
 #'   exibble %>%
 #'   gt(rowname_col = "row", groupname_col = "group") %>%
@@ -663,26 +695,34 @@ opt_table_lines <- function(data,
 #'   ) %>%
 #'   opt_table_outline()
 #'
-#' # Remove the table outline with the
-#' # `style = "none"` option
-#' tab_2 <-
-#'   tab_1 %>%
-#'   opt_table_outline(style = "none")
+#' tab_1
+#' ```
 #'
-#' @section Figures:
-#' \if{html}{\figure{man_opt_table_outline_1.png}{options: width=100\%}}
+#' \if{html}{\out{
+#' `r man_get_image_tag(file = "man_opt_table_outline_1.png")`
+#' }}
 #'
-#' \if{html}{\figure{man_opt_table_outline_2.png}{options: width=100\%}}
+#' Remove the table outline with the `style = "none"` option.
+#'
+#' ```r
+#' tab_1 %>% opt_table_outline(style = "none")
+#' ```
+#'
+#' \if{html}{\out{
+#' `r man_get_image_tag(file = "man_opt_table_outline_2.png")`
+#' }}
 #'
 #' @family Table Option Functions
 #' @section Function ID:
 #' 9-8
 #'
 #' @export
-opt_table_outline <- function(data,
-                              style = "solid",
-                              width = px(3),
-                              color = "#D3D3D3") {
+opt_table_outline <- function(
+    data,
+    style = "solid",
+    width = px(3),
+    color = "#D3D3D3"
+) {
 
   # Perform input object validation
   stop_if_not_gt(data = data)
@@ -751,19 +791,16 @@ opt_table_outline <- function(data,
 #'
 #' @return An object of class `gt_tbl`.
 #'
-#' @examples
-#' if (interactive()) {
+#' @section Examples:
 #'
-#' # Use `sp500` to create a small gt table,
-#' # using `fmt_currency()` to provide a
-#' # dollar sign for the first row of monetary
-#' # values; then, set a larger font size for
-#' # the table and use the 'Merriweather' font
-#' # (from Google Fonts, via `google_font()`)
-#' # with two font fallbacks ('Cochin' and the
-#' # catchall 'Serif' group)
-#' tab_1 <-
-#'   sp500 %>%
+#' Use [`sp500`] to create a small **gt** table, using [fmt_currency()] to
+#' provide a dollar sign for the first row of monetary values. Then, set a
+#' larger font size for the table and use the `"Merriweather"` font (from
+#' *Google Fonts*, via [google_font()]) with two font fallbacks (`"Cochin"` and
+#' the catchall `"Serif"` group).
+#'
+#' ```r
+#' sp500 %>%
 #'   dplyr::slice(1:10) %>%
 #'   dplyr::select(-volume, -adj_close) %>%
 #'   gt() %>%
@@ -780,16 +817,18 @@ opt_table_outline <- function(data,
 #'       "Cochin", "Serif"
 #'     )
 #'   )
+#' ```
 #'
-#' # Use `sza` to create an eleven-row table;
-#' # within `opt_table_font()`, set up a
-#' # preferred list of sans-serif fonts that
-#' # are commonly available in macOS (using
-#' # part of the `default_fonts()` vector as
-#' # a fallback)
-#' # and Windows 10
-#' tab_2 <-
-#'   sza %>%
+#' \if{html}{\out{
+#' `r man_get_image_tag(file = "man_opt_table_font_1.png")`
+#' }}
+#'
+#' Use [`sza`] to create an eleven-row table. Within `opt_table_font()`, set up
+#' a preferred list of sans-serif fonts that are commonly available in macOS
+#' (using part of the [default_fonts()] vector as a fallback).
+#'
+#' ```r
+#' sza %>%
 #'   dplyr::filter(
 #'     latitude == 20 &
 #'       month == "jan" &
@@ -804,24 +843,24 @@ opt_table_outline <- function(data,
 #'     )
 #'   ) %>%
 #'   opt_all_caps()
+#' ```
 #'
-#' }
-#'
-#' @section Figures:
-#' \if{html}{\figure{man_opt_table_font_1.png}{options: width=100\%}}
-#'
-#' \if{html}{\figure{man_opt_table_font_2.png}{options: width=100\%}}
+#' \if{html}{\out{
+#' `r man_get_image_tag(file = "man_opt_table_font_2.png")`
+#' }}
 #'
 #' @family Table Option Functions
 #' @section Function ID:
 #' 9-9
 #'
 #' @export
-opt_table_font <- function(data,
-                           font,
-                           weight = NULL,
-                           style = NULL,
-                           add = TRUE) {
+opt_table_font <- function(
+    data,
+    font,
+    weight = NULL,
+    style = NULL,
+    add = TRUE
+) {
 
   existing_fonts <-
     dt_options_get_value(
@@ -902,14 +941,14 @@ opt_table_font <- function(data,
 #'
 #' @return An object of class `gt_tbl`.
 #'
-#' @examples
-#' # Use `exibble` to create a gt table and
-#' # format the data in both columns; with
-#' # `opt_css()` insert CSS rulesets as
-#' # as string and be sure to set the table
-#' # ID explicitly (here as "one")
-#' tab_1 <-
-#'   exibble %>%
+#' @section Examples:
+#'
+#' Use [`exibble`] to create a **gt** table and format the data in both columns.
+#' With `opt_css()`, insert CSS rulesets as as string and be sure to set the
+#' table ID explicitly (here as `"one"`).
+#'
+#' ```r
+#' exibble %>%
 #'   dplyr::select(num, currency) %>%
 #'   gt(id = "one") %>%
 #'   fmt_currency(
@@ -932,19 +971,23 @@ opt_table_font <- function(data,
 #'     }
 #'     "
 #'   )
+#' ```
 #'
-#' @section Figures:
-#' \if{html}{\figure{man_opt_css_1.png}{options: width=100\%}}
+#' \if{html}{\out{
+#' `r man_get_image_tag(file = "man_opt_css_1.png")`
+#' }}
 #'
 #' @family Table Option Functions
 #' @section Function ID:
 #' 9-10
 #'
 #' @export
-opt_css <- function(data,
-                    css,
-                    add = TRUE,
-                    allow_duplicates = FALSE) {
+opt_css <- function(
+    data,
+    css,
+    add = TRUE,
+    allow_duplicates = FALSE
+) {
 
   existing_additional_css <-
     dt_options_get_value(
