@@ -32,8 +32,11 @@ test_that("all exported functions validate the incoming `data` object", {
   expect_error(exibble %>% fmt_datetime(), regexp = regexp_stop)
   expect_error(exibble %>% fmt_markdown(), regexp = regexp_stop)
   expect_error(exibble %>% fmt_passthrough(), regexp = regexp_stop)
-  expect_error(exibble %>% fmt_missing(), regexp = regexp_stop)
   expect_error(exibble %>% text_transform(), regexp = regexp_stop)
+  expect_error(exibble %>% sub_missing(), regexp = regexp_stop)
+  expect_error(exibble %>% sub_zero(), regexp = regexp_stop)
+  expect_error(exibble %>% sub_small_vals(), regexp = regexp_stop)
+  expect_error(exibble %>% sub_large_vals(), regexp = regexp_stop)
   expect_error(exibble %>% data_color(), regexp = regexp_stop)
   expect_error(exibble %>% cols_align(), regexp = regexp_stop)
   expect_error(exibble %>% cols_width(), regexp = regexp_stop)
