@@ -14,7 +14,7 @@ test_that("the `cols_align()` function works correctly", {
   # Create a `tbl_latex` object with `gt()`; the `mpg`,
   # `cyl`, and `drat` columns are aligned left
   tbl_latex <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_align(align = "left", columns = c(mpg, cyl, drat)) %>%
     as_latex() %>% as.character()
 
@@ -25,7 +25,7 @@ test_that("the `cols_align()` function works correctly", {
   # Create a `tbl_latex` object with `gt()`; columns `1` (`mpg`),
   # `2` (`cyl`), and `3` (`disp`) are aligned right
   tbl_latex <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_align(align = "left", columns = 1:3) %>%
     as_latex() %>% as.character()
 
@@ -36,7 +36,7 @@ test_that("the `cols_align()` function works correctly", {
   # Create a `tbl_latex` object with `gt()`; align all
   # columns to the left
   tbl_latex <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_align(align = "left") %>%
     as_latex() %>% as.character()
 
@@ -47,7 +47,7 @@ test_that("the `cols_align()` function works correctly", {
   # Create a `tbl_latex` object with `gt()`; align all
   # columns (using `columns = everything()`) to the left
   tbl_latex <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_align(align = "left", columns = everything()) %>%
     as_latex() %>% as.character()
 
@@ -58,7 +58,7 @@ test_that("the `cols_align()` function works correctly", {
   # Create a `tbl_latex` object with the `sp500` data
   # frame and `auto`-align all columns
   tbl_latex <-
-    gt(data = sp500) %>%
+    gt(sp500) %>%
     cols_align(align = "auto") %>%
     as_latex() %>% as.character()
 
